@@ -7,7 +7,7 @@ from sqlconstructor.constants import OR_MODE
 def test_or_two_filters():
     first_filter = SqlFilter({'a': 1})
     second_filter = SqlFilter({'b': 2})
-    assert (first_filter | second_filter) == '\n'.join(
+    assert str(first_filter | second_filter) == '\n'.join(
         (
             'a=1',
             OR_MODE,
@@ -20,7 +20,7 @@ def test_or_three_filters():
     first_filter = SqlFilter({'a': 1})
     second_filter = SqlFilter({'b': 2})
     third_filter = SqlFilter({'c': 3})
-    assert (first_filter | second_filter | third_filter) == '\n'.join(
+    assert str(first_filter | second_filter | third_filter) == '\n'.join(
         (
             'a=1',
             OR_MODE,
